%
% Matlab commands to plot time-series of results from MOORING*.q4d files
%   Plots 3-panel plots of Temperature, epsilon (tke dissip rate) 
%      and E_H (the mixing coefficient from a Q4 run).  [Note PSQ4
%      does not output the vertical mixing coefficients.]
%
%  Cisco Werner (May 1999)
%
%  The contents of the input files were written by Quoddy as:
%
%         write(nf1+IM,'(f9.5,12e13.5)')ydgmt0,
%     &   zpt,upt,vpt,wpt,rhopt,tpt,spt,q2pt,q2lpt,enzmpt,enzhpt,enzqpt
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%    
% load Stations: 95 Mixed; 100 Front; 106 Stratified
%
load('/mnt/ljaz/May20_FCAST/CRUISE_Q4.3/MOORING2.Q4.q4d'); % Stn 95
m2=MOORING2;
load('/mnt/ljaz/May20_FCAST/CRUISE_Q4.3/MOORING3.Q4.q4d'); % Stn 100
m3=MOORING3;
load('/mnt/ljaz/May20_FCAST/CRUISE_Q4.3/MOORING4.Q4.q4d'); % Stn 106
m4=MOORING4;

load('/mnt/ljaz/May20_FCAST/CRUISE_Q4.OUTPUT/Q4.3/MOORING2.Q4.q4d'); % Stn 95
m2=MOORING2;
load('/mnt/ljaz/May20_FCAST/CRUISE_Q4.OUTPUT/Q4.3/MOORING3.Q4.q4d'); % Stn 100
m3=MOORING3;
load('/mnt/ljaz/May20_FCAST/CRUISE_Q4.OUTPUT/Q4.3/MOORING4.Q4.q4d'); % Stn 106
m4=MOORING4;
clear MOORING2;
clear MOORING3;
clear MOORING4;

% 
% extract time and depth
%

nz=21;

z2=m2(1:nz,2);
z3=m3(1:nz,2);
z4=m4(1:nz,2);
zmin2=min(z2);zmax2=max(z2);
zmin3=min(z3);zmax3=max(z3);
zmin4=min(z4);zmax4=max(z4);

% shift time to day in May local EDT 
%
t2=m2(1:nz:length(m2),1)-119-4/24;
lt2=length(t2);
tmin2=min(t2);
tmax2=max(t2);
%
t3=m3(1:nz:length(m3),1)-119-4/24;
lt3=length(t3);
tmin3=min(t3);
tmax3=max(t3);
%
t4=m4(1:nz:length(m4),1)-119-4/24;
lt4=length(t4);
tmin4=min(t4);
tmax4=max(t4);

[t2,z2]=meshgrid(t2,z2);
[t3,z3]=meshgrid(t3,z3);
[t4,z4]=meshgrid(t4,z4);

% assign dependent variables to vectors
%
%   Station 95               Station 100              Station 106
%
u2=m2(1:length(m2),3);   u3=m3(1:length(m3),3);   u4=m4(1:length(m4),3);
v2=m2(1:length(m2),4);   v3=m3(1:length(m3),4);   v4=m4(1:length(m4),4);
w2=m2(1:length(m2),5);   w3=m3(1:length(m3),5);   w4=m4(1:length(m4),5);
rho2=m2(1:length(m2),6); rho3=m3(1:length(m3),6); rho4=m4(1:length(m4),6);
temp2=m2(1:length(m2),7);temp3=m3(1:length(m3),7);temp4=m4(1:length(m4),7);
sal2=m2(1:length(m2),8); sal3=m3(1:length(m3),8); sal4=m4(1:length(m4),8);
q22=m2(1:length(m2),9);  q23=m3(1:length(m3),9);  q24=m4(1:length(m4),9);
q2l2=m2(1:length(m2),10);q2l3=m3(1:length(m3),10);q2l4=m4(1:length(m4),10);
enzm2=m2(1:length(m2),11); enzm3=m3(1:length(m3),11);enzm4=m4(1:length(m4),11);  
enzh2=m2(1:length(m2),12);enzh3=m3(1:length(m3),12);enzh4=m4(1:length(m4),12);   
enzq2=m2(1:length(m2),13); enzq3=m3(1:length(m3),13);enzq4=m4(1:length(m4),13);  


% compute epsilon
%
%   Station 95         Station 100              Station 106
%
ell2=q2l2./q22;       ell3=q2l3./q23;       ell4=q2l4./q24;
q32=q22.^(1.5);       q33=q23.^(1.5);       q34=q24.^(1.5);
eps2=q32./ell2/16.6;  eps3=q33./ell3/16.6;  eps4=q34./ell4/16.6;

%
%plot espilons
%
figure

zminall=min([zmin2 zmin3 zmin4]);
zmaxall=max([zmax2 zmax3 zmax4]);
% the mixed station
%
subplot(311)         
%axis([tmin2 tmax2 zmin2 zmax2])
axis([tmin2 tmax2 zminall zmaxall])
epsilon2=reshape(eps2,nz,lt2);
colormap(jet)
h=surface(t2,z2,log10(epsilon2));set(h,'EdgeColor','interp','FaceColor','interp')
colorbar
%xlabel('Days in May 1999')
set(gca,'XTickLabel',' ')
ylabel('Depth (m)')
title('Station 95; log10(epsilon)')
set(gca,'clim',[-7 -4])
colorbar

% the frontal station
%
subplot(312)         
%axis([tmin3 tmax3 zmin3 zmax3])
axis([tmin3 tmax3 zminall zmaxall])
epsilon3=reshape(eps3,nz,lt3);
colormap(jet)
h=surface(t3,z3,log10(epsilon3));set(h,'EdgeColor','interp','FaceColor','interp')
colorbar
%xlabel('Days in May 1999')
set(gca,'XTickLabel',' ')
ylabel('Depth (m)')
title('Station 100; log10(epsilon)')
set(gca,'clim',[-7 -4])
colorbar

% the well mixed station
%
subplot(313)         
%axis([tmin4 tmax4 zmin4 zmax4])
axis([tmin4 tmax4 zminall zmaxall])
epsilon4=reshape(eps4,nz,lt4);
colormap(jet)
h=surface(t4,z4,log10(epsilon4));set(h,'EdgeColor','interp','FaceColor','interp')
colorbar
xlabel('Days in May 1999')
ylabel('Depth (m)')
title('Station 106; log10(epsilon)')
set(gca,'clim',[-7 -4])
colorbar


%
%plot temperatures
%
figure

zminall=min([zmin2 zmin3 zmin4]);
zmaxall=max([zmax2 zmax3 zmax4]);
% the mixed station
%
subplot(311)         
%axis([tmin2 tmax2 zmin2 zmax2])
axis([tmin2 tmax2 zminall zmaxall])
tempr2=reshape(temp2,nz,lt2);
colormap(jet)
h=surface(t2,z2,tempr2);set(h,'EdgeColor','interp','FaceColor','interp')
colorbar
%xlabel('Days in May 1999')
set(gca,'XTickLabel',' ')
ylabel('Depth (m)')
title('Station 95; Temperature')
set(gca,'clim',[7 10])
colorbar

% the frontal station
%
subplot(312)         
%axis([tmin3 tmax3 zmin3 zmax3])
axis([tmin3 tmax3 zminall zmaxall])
tempr3=reshape(temp3,nz,lt3);
colormap(jet)
h=surface(t3,z3,tempr3);set(h,'EdgeColor','interp','FaceColor','interp')
colorbar
%xlabel('Days in May 1999')
set(gca,'XTickLabel',' ')
ylabel('Depth (m)')
title('Station 100; Temperature')
set(gca,'clim',[7 10])
colorbar

% the well mixed station
%
subplot(313)         
%axis([tmin4 tmax4 zmin4 zmax4])
axis([tmin4 tmax4 zminall zmaxall])
tempr4=reshape(temp4,nz,lt4);
colormap(jet)
h=surface(t4,z4,tempr4);set(h,'EdgeColor','interp','FaceColor','interp')
colorbar
xlabel('Days in May 1999')
ylabel('Depth (m)')
title('Station 106; Temperature')
set(gca,'clim',[7 10])
colorbar


%
%plot viscosity
%
figure

zminall=min([zmin2 zmin3 zmin4]);
zmaxall=max([zmax2 zmax3 zmax4]);
% the mixed station
%
subplot(311)         
%axis([tmin2 tmax2 zmin2 zmax2])
axis([tmin2 tmax2 zminall zmaxall])
eh2=reshape(enzh2,nz,lt2);
colormap(jet)
h=surface(t2,z2,eh2);set(h,'EdgeColor','interp','FaceColor','interp')
colorbar
%xlabel('Days in May 1999')
set(gca,'XTickLabel',' ')
ylabel('Depth (m)')
title('Station 95; E_H')
set(gca,'clim',[0 0.3])
colorbar

% the frontal station
%
subplot(312)         
%axis([tmin3 tmax3 zmin3 zmax3])
axis([tmin3 tmax3 zminall zmaxall])
eh3=reshape(enzh3,nz,lt3);
colormap(jet)
h=surface(t3,z3,eh3);set(h,'EdgeColor','interp','FaceColor','interp')
colorbar
%xlabel('Days in May 1999')
set(gca,'XTickLabel',' ')
ylabel('Depth (m)')
title('Station 100; E_H')
set(gca,'clim',[0 0.3])
colorbar

% the well mixed station
%
subplot(313)         
%axis([tmin4 tmax4 zmin4 zmax4])
axis([tmin4 tmax4 zminall zmaxall])
eh4=reshape(enzh4,nz,lt4);
colormap(jet)
h=surface(t4,z4,eh4);set(h,'EdgeColor','interp','FaceColor','interp')
colorbar
xlabel('Days in May 1999')
ylabel('Depth (m)')
title('Station 106; E_H')
set(gca,'clim',[0 0.3])
colorbar

